Struct async_ssh::NewSession
[−]
[src]
pub struct NewSession<S: AsyncRead + AsyncWrite> { /* fields omitted */ }
A newly established, unauthenticated SSH session.
All you can really do with this in authenticate it using one of the authenticate_* methods.
You'll most likely want [NewSession::authenticate_key].
Methods
impl<S: AsyncRead + AsyncWrite + 'static> NewSession<S>[src]
ⓘImportant traits for Box<W>pub fn authenticate_key(
self,
user: &str,
key: KeyPair
) -> Box<Future<Item = Session<S>, Error = HandlerError<()>>> where
S: Tcp, [src]
ⓘImportant traits for Box<W>
self,
user: &str,
key: KeyPair
) -> Box<Future<Item = Session<S>, Error = HandlerError<()>>> where
S: Tcp,
Authenticate as the given user using the given keypair.